@@ -79,6 +79,9 @@ class KLocalizedStringPrivate;
  *
  * \c KLocalizedString instances are usually not constructed directly,
  * but through one of the wrapper \c \*i18n\* calls.
+ *
+ * For detailed information on how to use KI18n functions please refer
+ * to \ref prg_guide.
  */
 class KI18N_EXPORT KLocalizedString
 {
@@ -158,7 +161,7 @@ public:
      *
      * \return finalized translation
      */
-    QString toString() const;
+    QString toString() const Q_REQUIRED_RESULT;
 
     /**
      * Like \c toString, but look for translation only in given languages.
@@ -170,7 +173,7 @@ public:
      * \param languages list of language codes (by decreasing priority)
      * \return finalized translation
      */
-    QString toString(const QStringList &languages) const;
+    QString toString(const QStringList &languages) const Q_REQUIRED_RESULT;
 
 #if 0 // until locale system is ready
     /**
@@ -193,7 +196,7 @@ public:
      * \param domain the translation domain
      * \return finalized translation
      */
-    QString toString(const char *domain) const;
+    QString toString(const char *domain) const Q_REQUIRED_RESULT;
 
     /**
      * Like \c toString, but resolve KUIT markup into given visual format.
@@ -206,7 +209,7 @@ public:
      * \param format the target visual format
      * \return finalized translation
      */
-    QString toString(Kuit::VisualFormat format) const;
+    QString toString(Kuit::VisualFormat format) const Q_REQUIRED_RESULT;
 
     /**
      * Indicate to look for translation only in given languages.
@@ -214,7 +217,7 @@ public:
      * \param languages list of language codes (by decreasing priority)
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withLanguages(const QStringList &languages) const;
+    KLocalizedString withLanguages(const QStringList &languages) const Q_REQUIRED_RESULT;
 
 #if 0 // until locale system is ready
     /**
@@ -232,7 +235,7 @@ public:
      * \param domain the translation domain
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withDomain(const char *domain) const;
+    KLocalizedString withDomain(const char *domain) const Q_REQUIRED_RESULT;
 
     /**
      * Indicate to resolve KUIT markup into given visual format.
@@ -242,7 +245,7 @@ public:
      * \param format the target visual format
      * \return updated \c KLocalizedString
      */
-    KLocalizedString withFormat(Kuit::VisualFormat format) const;
+    KLocalizedString withFormat(Kuit::VisualFormat format) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute an int argument into the message.
@@ -257,7 +260,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(int a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute an unsigned int argument into the message.
@@ -272,7 +275,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(uint a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute a long argument into the message.
@@ -287,7 +290,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(long a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute an unsigned long argument into the message.
@@ -302,7 +305,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(ulong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute a long long argument into the message.
@@ -317,7 +320,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(qlonglong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute an unsigned long long argument into the message.
@@ -332,7 +335,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(qulonglong a, int fieldWidth = 0, int base = 10,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute a double argument into the message.
@@ -348,7 +351,7 @@ public:
      */
     KLocalizedString subs(double a, int fieldWidth = 0,
                           char format = 'g', int precision = -1,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute a \c QChar argument into the message.
@@ -361,7 +364,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(QChar a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute a \c QString argument into the message.
@@ -374,7 +377,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(const QString &a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Substitute another \c KLocalizedString into the message.
@@ -387,7 +390,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString subs(const KLocalizedString &a, int fieldWidth = 0,
-                          QChar fillChar = QLatin1Char(' ')) const;
+                          QChar fillChar = QLatin1Char(' ')) const Q_REQUIRED_RESULT;
 
     /**
      * Add dynamic context to the message.
@@ -399,7 +402,7 @@ public:
      * \return updated \c KLocalizedString
      */
     KLocalizedString inContext(const QString &key,
-                               const QString &value) const;
+                               const QString &value) const Q_REQUIRED_RESULT;
 
     /**
      * Relax matching between placeholders and arguments.
@@ -418,7 +421,7 @@ public:
      *
      * \return updated \c KLocalizedString
      */
-    KLocalizedString relaxSubs() const;
+    KLocalizedString relaxSubs() const Q_REQUIRED_RESULT;
 
     /**
      * Do not resolve KUIT markup.
@@ -430,7 +433,7 @@ public:
      *
      * \return updated \c KLocalizedString
      */
-    KLocalizedString ignoreMarkup() const;
+    KLocalizedString ignoreMarkup() const Q_REQUIRED_RESULT;
 
     /**
      * Set the given domain as application's main domain.
@@ -467,6 +470,19 @@ public:
     static void setLocale(const KLocale &locale);
 #endif
 
+    /**
+     * Get the languages for which translations will be made.
+     *
+     * Returned languages are ordered with decreasing priority.
+     *
+     * \return languages ordered list of language codes
+     * \see setLanguages
+     * \see clearLanguages
+     *
+     * \since 5.20.0
+     */
+    static QStringList languages();
+
     /**
      * Set the languages for which translations will be made.
      *
@@ -476,6 +492,7 @@ public:
      * \param languages ordered list of language codes
      * \see setLocale
      * \see clearLanguages
+     * \see languages
      */
     static void setLanguages(const QStringList &languages);
 
@@ -486,6 +503,7 @@ public:
      * provided by the locale.
      *
      * \see setLanguages
+     * \see languages
      */
     static void clearLanguages();
 
@@ -516,6 +534,27 @@ public:
      */
     static QSet<QString> availableApplicationTranslations();
 
+    /**
+     * @since 5.0
+     *
+     * Get the languages for which a translation catalog file
+     * for the passed translation domain exists.
+     *
+     * If the translation domain was not specified in the
+     * domain parameter an empty set is returned.
+     *
+     * If the application domain was set, the language set will always
+     * contain at least the source code language (<tt>en_US</tt>).
+     *
+     * \param domain query for translations of a specific domain, if an empty
+     * QByteArray is passed, an empty set will be returned
+     *
+     * \return set of language codes for existing translation catalogs
+     * \see setApplicationDomain
+     * \see availableApplicationTranslations
+     */
+    static QSet<QString> availableDomainTranslations(const QByteArray &domain);
+
     /**
      * Find a path to the localized file for the given original path.
      *
@@ -531,7 +570,7 @@ public:
      *
      * \return path to the localized file if found, original path otherwise
      */
-    static QString localizedFilePath(const QString &filePath);
+    static QString localizedFilePath(const QString &filePath) Q_REQUIRED_RESULT;
 
     /**
      * Remove accelerator marker from a UI text label.
@@ -547,7 +586,7 @@ public:
      * \param label UI label which may contain an accelerator marker
      * \return label without the accelerator marker
      */
-    static QString removeAcceleratorMarker(const QString &label);
+    static QString removeAcceleratorMarker(const QString &label) Q_REQUIRED_RESULT;
 
     /**
      * Translate a message with Qt semantics.
@@ -564,8 +603,8 @@ public:
      *             with roundtrip TS->PO->TS through
      *             Qt's \c lupdate and \c lconvert commands.
      */
-    static QString translateQt(const char *context, const char *text,
-                               const char *comment, int n);
+    KI18N_DEPRECATED static QString translateQt(const char *context, const char *text,
+                               const char *comment, int n) Q_REQUIRED_RESULT;
 
     /**
      * Add another domain to search for Qt translations.
@@ -577,7 +616,7 @@ public:
      *
      * \deprecated
      */
-    static void insertQtDomain(const char *domain);
+    KI18N_DEPRECATED static void insertQtDomain(const char *domain);
 
     /**
      * Remove a domain from Qt translation lookup.
@@ -595,7 +634,7 @@ public:
      *
      * \deprecated
      */
-    static void removeQtDomain(const char *domain);
+    KI18N_DEPRECATED static void removeQtDomain(const char *domain);
 
 private:
     KLocalizedString(const char *domain,
@@ -974,7 +1013,7 @@ KLocalizedString KI18N_EXPORT kxi18ndcp(const char *domain, const char *context,
  * \param comment Qt equivalent of disambiguation context
  * \return translated string
  */
-inline QString tr2i18n(const char *text, const char *comment = 0)
+inline QString tr2i18n(const char *text, const char *comment = nullptr)
 {
     if (comment && comment[0] && text && text[0]) {
         return ki18nc(comment, text).toString();
@@ -996,7 +1035,7 @@ inline QString tr2i18n(const char *text, const char *comment = 0)
  * \return translated string
  */
 inline QString tr2i18nd(const char *domain,
-                        const char *text, const char *comment = 0)
+                        const char *text, const char *comment = nullptr)
 {
     if (comment && comment[0] && text && text[0]) {
         return ki18ndc(domain, comment, text).toString();
@@ -1016,7 +1055,7 @@ inline QString tr2i18nd(const char *domain,
  * \param comment Qt equivalent of disambiguation context
  * \return translated string
  */
-inline QString tr2xi18n(const char *text, const char *comment = 0)
+inline QString tr2xi18n(const char *text, const char *comment = nullptr)
 {
     if (comment && comment[0] && text && text[0]) {
         return kxi18nc(comment, text).toString();
@@ -1038,7 +1077,7 @@ inline QString tr2xi18n(const char *text, const char *comment = 0)
  * \return translated string
  */
 inline QString tr2xi18nd(const char *domain,
-                         const char *text, const char *comment = 0)
+                         const char *text, const char *comment = nullptr)
 {
     if (comment && comment[0] && text && text[0]) {
         return kxi18ndc(domain, comment, text).toString();
